from sisense.resource import Resource


class Group(Resource):

    def get(self, name: str = None, oid: str = None) -> Resource:
        """Get group by name. At least one parameter should be set.

        :param name: (str, default None) Group's name.
        :param oid: (str, default None) Group's ID.
        :return: Group, if found. None, otherwise.
        """
        if oid:
            content = self._api.get(f'groups/{oid}')
        elif name:
            content = self._api.get('groups', query={'name': name})
            content = content[0] if len(content) else None
        else:
            raise ValueError('At least one parameter should be set.')

        return Group(self._api, content) if content else None

    def create(self, name: str) -> Resource:
        """
        Create a new group.

        :param name: (str) Group's name.
        :return: (Group) Newly created group.
        """
        data = {'name': name}
        content = self._api.post('groups', data=data)

        return Group(self._api, content)

    def delete(self):
        """Delete the current group."""
        self._api.delete(f'groups/{self._id}')



from .test_case import TestCaseV1 as TestCase
from sisense.admin import Group


class GroupTestCase(TestCase):

    def test_get(self):
        group = self.sisense.group.get(self.config['group_name'])
        self.assertEqual(group.name, self.config['group_name'])

        same = self.sisense.group.get(oid=group._id)
        self.assertEqual(group._id, same._id)
        self.assertEqual(group.name, same.name)

    def create(self):
        group = self.sisense.group.create(self.config['group_name'])

        self.assertIsInstance(group, Group)
        self.assertEqual(group.name, self.config['group_name'])

    def delete(self):
        group = self.sisense.group.get(self.config['group_name'])
        if group:
            group.delete()

            group = self.sisense.group.get(self.config['group_name'])
            self.assertEqual(group, None)



from sisense.resource import Resource


class User(Resource):

    def get(self, email: str = None, oid: str = None) -> Resource:
        """Get user by e-mail. At least one parameter should be set.

        :param email: (str, default None) User's e-mail.
        :param oid: (str, default None) User's ID.
        :return: User, if found. None, otherwise.
        """
        if oid:
            content = self._api.get(f'users/{oid}')
        elif email:
            content = self._api.get('users', query={'email': email})
            content = content[0] if len(content) else None
        else:
            raise ValueError('At least one parameter should be set.')

        return User(self._api, content) if content else None

    def create(self, email: str, **kwargs) -> Resource:
        """
        Create a new user.

        :param email: (str) User's email.
        :param kwargs: (dict) Optional keyword arguments:
            - userName: (str) Username.
            - firstName: (str) First name.
            - lastName: (str) Last name.
            - roleId: (str) Role's ID.
            - groups: (list) Group's ID in which user is part of.
        :return: (User) Newly created user.
        """
        data = {'email': email}
        data.update(kwargs)

        content = self._api.post('users', data=data)
        return User(self._api, content)

    def delete(self):
        """Delete the current user."""
        self._api.delete(f'users/{self._id}')
